@@ -15,7 +15,7 @@ module Timeliness
     def unambiguous_year(year)
       if year.length <= 2
         century = Time.now.year.to_s[0..1].to_i
-        century -= 1 if year.to_i >= Timeliness.ambiguous_year_threshold
+        century -= 1 if year.to_i >= Timeliness.configuration.ambiguous_year_threshold
         year = "#{century}#{year.rjust(2,'0')}"
       end
       year.to_i
@@ -23,7 +23,7 @@ module Timeliness
     
     def month_index(month)
       return month.to_i if month.to_i > 0 || /0+/ =~ month
-      month.length > 3 ? month_names.index(month.capitalize) : abbr_month_names.index(month.capitalize)
+      (month.length > 3 ? month_names : abbr_month_names).index { |str| month.casecmp?(str) }
     end
 
     def month_names
