@@ -1,4 +1,17 @@
 describe Timeliness::Parser do
+  def self.timezone_settings(zone: nil, output: nil)
+    before do
+      Time.zone = zone if zone
+      Timeliness.configuration.default_timezone = output if output 
+    end
+  end
+
+  around do |example|
+    current_zone = Time.zone
+    example.call
+    Time.zone = current_zone
+  end
+
   before(:all) do
     Timecop.freeze(2010,1,1,0,0,0)
   end
@@ -70,10 +83,7 @@ describe Timeliness::Parser do
 
     context "string with zone offset value" do
       context "when current timezone is earler than string zone" do
-        before(:all) do
-          Timeliness.default_timezone = :current
-          Time.zone = 'Australia/Melbourne'
-        end
+        timezone_settings zone: 'Australia/Melbourne', output: :current
 
         it 'should return value shifted by positive offset in default timezone' do
           value = parse("2000-06-01T12:00:00+02:00")
@@ -86,67 +96,63 @@ describe Timeliness::Parser do
           expect(value).to eq Time.zone.local(2000,6,1,23,0,0)
           expect(value.utc_offset).to eq 10.hours
         end
-
-        after(:all) do
-          Time.zone = nil
-          Timeliness.default_timezone = :local
-        end
       end
 
       context "when current timezone is later than string zone" do
-        before(:all) do
-          Timeliness.default_timezone = :current
-          Time.zone = 'America/Phoenix'
-        end
+        timezone_settings zone: 'America/Phoenix', output: :current
 
         it 'should return value shifted by positive offset in default timezone' do
           value = parse("2000-06-01T12:00:00+02:00")
           expect(value).to eq Time.zone.local(2000,6,1,3,0,0)
-          expect(value.utc_offset).to eq -7.hours
+          expect(value.utc_offset).to eq(-7.hours)
         end
 
         it 'should return value shifted by negative offset in default timezone' do
           value = parse("2000-06-01T12:00:00-01:00")
           expect(value).to eq Time.zone.local(2000,6,1,6,0,0)
-          expect(value.utc_offset).to eq -7.hours
-        end
-
-        after(:all) do
-          Time.zone = nil
-          Timeliness.default_timezone = :local
+          expect(value.utc_offset).to eq(-7.hours)
         end
       end
     end
 
     context "string with zone abbreviation" do
-      before(:all) do
-        Time.zone = 'Australia/Melbourne'
-      end
+      timezone_settings zone: 'Australia/Melbourne'
 
       it 'should return value using string zone adjusted to default :local timezone' do
-        Timeliness.default_timezone = :local
+        Timeliness.configuration.default_timezone = :local
+
         value = parse("Thu, 01 Jun 2000 03:00:00 MST")
         expect(value).to eq Time.utc(2000,6,1,10,0,0).getlocal
         expect(value.utc_offset).to eq Time.mktime(2000, 6, 1, 10, 0, 0).utc_offset
       end
 
       it 'should return value using string zone adjusted to default :current timezone' do
-        Timeliness.default_timezone = :current
+        Timeliness.configuration.default_timezone = :current
         Time.zone = 'Adelaide'
+
         value = parse("Thu, 01 Jun 2000 03:00:00 MST")
         expect(value).to eq Time.zone.local(2000,6,1,19,30,0)
         expect(value.utc_offset).to eq 9.5.hours
       end
 
       it 'should return value using string zone adjusted to :zone option string timezone' do
-        Timeliness.default_timezone = :local
-        value = parse("Thu, 01 Jun 2000 03:00:00 MST", :zone => 'Perth')
+        Timeliness.configuration.default_timezone = :local
+
+        value = parse("Thu, 01 Jun 2000 03:00:00 MST", zone: 'Perth')
         expect(value).to eq Time.use_zone('Perth') { Time.zone.local(2000,6,1,18,0,0) }
         expect(value.utc_offset).to eq 8.hours
       end
+    end
 
-      after(:all) do
-        Time.zone = nil
+    context "string with zulu time abbreviation 'Z'" do
+      timezone_settings zone: 'Australia/Melbourne'
+      
+      it 'should return value using string zone adjusted to default :current timezone' do
+        Timeliness.configuration.default_timezone = :current
+
+        value = parse("2000-06-01T12:00:00Z")
+        expect(value).to eq Time.zone.local(2000,6,1,22,0,0)
+        expect(value.utc_offset).to eq 10.hours
       end
     end
 
@@ -190,7 +196,7 @@ describe Timeliness::Parser do
 
     context "with :now option" do
       it 'should use date parts if string does not specify' do
-        time = parse("12:13:14", :now => Time.local(2010,1,1))
+        time = parse("12:13:14", now: Time.local(2010,1,1))
         expect(time).to eq Time.local(2010,1,1,12,13,14)
       end
     end
@@ -205,46 +211,47 @@ describe Timeliness::Parser do
     context "with :zone option" do
       context ":utc" do
         it "should return time object in utc timezone" do
-          time = parse("2000-06-01 12:13:14", :datetime, :zone => :utc)
+          time = parse("2000-06-01 12:13:14", :datetime, zone: :utc)
           expect(time.utc_offset).to eq 0
         end
 
         it 'should return nil for partial invalid time component' do
-          expect(parse("2000-06-01 12:60", :datetime, :zone => :utc)).to be_nil
+          expect(parse("2000-06-01 12:60", :datetime, zone: :utc)).to be_nil
         end
       end
 
       context ":local" do
         it "should return time object in local system timezone" do
-          time = parse("2000-06-01 12:13:14", :datetime, :zone => :local)
+          time = parse("2000-06-01 12:13:14", :datetime, zone: :local)
           expect(time.utc_offset).to eq Time.mktime(2000, 6, 1, 12, 13, 14).utc_offset
         end
 
         it 'should return nil for partial invalid time component' do
-          expect(parse("2000-06-01 12:60", :datetime, :zone => :local)).to be_nil
+          expect(parse("2000-06-01 12:60", :datetime, zone: :local)).to be_nil
         end
       end
 
       context ":current" do
+        timezone_settings zone: 'Adelaide'
+
         it "should return time object in current timezone" do
-          Time.zone = 'Adelaide'
-          time = parse("2000-06-01 12:13:14", :datetime, :zone => :current)
+          time = parse("2000-06-01 12:13:14", :datetime, zone: :current)
           expect(time.utc_offset).to eq 9.5.hours
         end
 
         it 'should return nil for partial invalid time component' do
-          expect(parse("2000-06-01 12:60", :datetime, :zone => :current)).to be_nil
+          expect(parse("2000-06-01 12:60", :datetime, zone: :current)).to be_nil
         end
       end
 
       context "named zone" do
         it "should return time object in the timezone" do
-          time = parse("2000-06-01 12:13:14", :datetime, :zone => 'London')
+          time = parse("2000-06-01 12:13:14", :datetime, zone: 'London')
           expect(time.utc_offset).to eq 1.hour
         end
 
         it 'should return nil for partial invalid time component' do
-          expect(parse("2000-06-01 12:60", :datetime, :zone => 'London')).to be_nil
+          expect(parse("2000-06-01 12:60", :datetime, zone: 'London')).to be_nil
         end
       end
 
@@ -252,17 +259,17 @@ describe Timeliness::Parser do
         it 'should output message' do
           expect {
             expect(Time).to receive(:zone).and_raise(NoMethodError.new("undefined method `zone' for Time:Class"))
-            parse("2000-06-01 12:13:14", :zone => :current)
+            parse("2000-06-01 12:13:14", zone: :current)
           }.to raise_error(Timeliness::Parser::MissingTimezoneSupport)
 
           expect {
             expect(Time).to receive(:current).and_raise(NoMethodError.new("undefined method `current' for Time:Class"))
-            parse("12:13:14", :zone => :current)
+            parse("12:13:14", zone: :current)
           }.to raise_error(Timeliness::Parser::MissingTimezoneSupport)
 
           expect {
             expect(Time).to receive(:use_zone).and_raise(NoMethodError.new("undefined method `use_zone' for Time:Class"))
-            parse("2000-06-01 12:13:14", :zone => 'London')
+            parse("2000-06-01 12:13:14", zone: 'London')
           }.to raise_error(Timeliness::Parser::MissingTimezoneSupport)
         end
       end
@@ -270,48 +277,40 @@ describe Timeliness::Parser do
 
     context "for time type" do
       context "with date from date_for_time_type" do
-        before do
-          @original = Timeliness.date_for_time_type
-        end
-
         it 'should return date array' do
-          Timeliness.date_for_time_type = [2010,1,1]
+          Timeliness.configuration.date_for_time_type = [2010,1,1]
+
           expect(parse('12:13:14', :time)).to eq Time.local(2010,1,1,12,13,14)
         end
 
         it 'should return date array evaluated lambda' do
-          Timeliness.date_for_time_type = lambda { Time.local(2010,2,1) }
-          expect(parse('12:13:14', :time)).to eq Time.local(2010,2,1,12,13,14)
-        end
+          Timeliness.configuration.date_for_time_type = lambda { Time.local(2010,2,1) }
 
-        after do
-          Timeliness.date_for_time_type = @original
+          expect(parse('12:13:14', :time)).to eq Time.local(2010,2,1,12,13,14)
         end
       end
 
       context "with :now option" do
         it 'should use date from :now' do
-          expect(parse('12:13:14', :time, :now => Time.local(2010, 6, 1))).to eq Time.local(2010,6,1,12,13,14)
+          expect(parse('12:13:14', :time, now: Time.local(2010, 6, 1))).to eq Time.local(2010,6,1,12,13,14)
         end
       end
 
       context "with :zone option" do
         before(:all) do
-          Timecop.return
           @current_tz = ENV['TZ']
           ENV['TZ'] = 'Australia/Melbourne'
           Timecop.freeze(2010,1,1,0,0,0)
         end
 
         it "should use date from the specified zone" do
-          time = parse("12:13:14", :time, :zone => :utc)
+          time = parse("12:13:14", :time, zone: :utc)
           expect(time.year).to eq 2009
           expect(time.month).to eq 12
           expect(time.day).to eq 31
         end
 
         after(:all) do
-          Timecop.return
           ENV['TZ'] = @current_tz
           Timecop.freeze(2010,1,1,0,0,0)
         end
@@ -375,51 +374,51 @@ describe Timeliness::Parser do
       end
     end
 
-    context "with :strict => true" do
+    context "with strict: true" do
       it "should return nil from date string when type is datetime" do
-        time_array = parser._parse('2000-02-01', :datetime, :strict => true)
+        time_array = parser._parse('2000-02-01', :datetime, strict: true)
         expect(time_array).to be_nil
       end
 
       it "should return nil from datetime string when type is date" do
-        time_array = parser._parse('2000-02-01 12:13:14', :date, :strict => true)
+        time_array = parser._parse('2000-02-01 12:13:14', :date, strict: true)
         expect(time_array).to be_nil
       end
 
       it "should return nil from datetime string when type is time" do
-        time_array = parser._parse('2000-02-01 12:13:14', :time, :strict => true)
+        time_array = parser._parse('2000-02-01 12:13:14', :time, strict: true)
         expect(time_array).to be_nil
       end
 
       it "should parse date string when type is date" do
-        time_array = parser._parse('2000-02-01', :date, :strict => true)
+        time_array = parser._parse('2000-02-01', :date, strict: true)
         expect(time_array).not_to be_nil
       end
 
       it "should parse time string when type is time" do
-        time_array = parser._parse('12:13:14', :time, :strict => true)
+        time_array = parser._parse('12:13:14', :time, strict: true)
         expect(time_array).not_to be_nil
       end
 
       it "should parse datetime string when type is datetime" do
-        time_array = parser._parse('2000-02-01 12:13:14', :datetime, :strict => true)
+        time_array = parser._parse('2000-02-01 12:13:14', :datetime, strict: true)
         expect(time_array).not_to be_nil
       end
 
       it "should ignore strict parsing if no type specified" do
-        time_array = parser._parse('2000-02-01', :strict => true)
+        time_array = parser._parse('2000-02-01', strict: true)
         expect(time_array).not_to be_nil
       end
     end
 
     context "with :format option" do
       it "should return values if string matches specified format" do
-        time_array = parser._parse('2000-02-01 12:13:14', :datetime, :format => 'yyyy-mm-dd hh:nn:ss')
+        time_array = parser._parse('2000-02-01 12:13:14', :datetime, format: 'yyyy-mm-dd hh:nn:ss')
         expect(time_array).to eq [2000,2,1,12,13,14,nil,nil]
       end
 
       it "should return nil if string does not match specified format" do
-        time_array = parser._parse('2000-02-01 12:13', :datetime, :format => 'yyyy-mm-dd hh:nn:ss')
+        time_array = parser._parse('2000-02-01 12:13', :datetime, format: 'yyyy-mm-dd hh:nn:ss')
         expect(time_array).to be_nil
       end
     end
@@ -436,13 +435,12 @@ describe Timeliness::Parser do
       end
 
       it "should allow custom threshold" do
-        default = Timeliness.ambiguous_year_threshold
-        Timeliness.ambiguous_year_threshold = 40
+        Timeliness.configuration.ambiguous_year_threshold = 40
+
         time_array = parser._parse('01-02-39', :date)
         expect(time_array).to eq [2039,2,1,nil,nil,nil,nil,nil]
         time_array = parser._parse('01-02-40', :date)
         expect(time_array).to eq [1940,2,1,nil,nil,nil,nil,nil]
-        Timeliness.ambiguous_year_threshold = default
       end
     end
   end
@@ -469,19 +467,12 @@ describe Timeliness::Parser do
     end
 
     context "default timezone" do
-      before do
-        @default_timezone = Timeliness.default_timezone
-      end
-
       it "should be used if no zone value" do
-        Timeliness.default_timezone = :utc
+        Timeliness.configuration.default_timezone = :utc
+
         time = parser.make_time([2000,6,1,12,0,0])
         expect(time.utc_offset).to eq 0
       end
-
-      after do
-       Timeliness.default_timezone = @default_timezone
-      end
     end
 
     context "with zone value" do
@@ -520,7 +511,7 @@ describe Timeliness::Parser do
 
     context "with no options" do
       it 'should return date_for_time_type values with no options' do
-        dummy_date = Timeliness.date_for_time_type.call
+        dummy_date = Timeliness.configuration.date_for_time_type.call
         expect(current_date).to eq [ dummy_date.year, dummy_date.month, dummy_date.day ]
       end
     end
@@ -529,7 +520,7 @@ describe Timeliness::Parser do
       it 'should return date array from Time value' do
         time = Time.now
         date_array = [time.year, time.month, time.day]
-        expect(current_date(:now => time)).to eq date_array
+        expect(current_date(now: time)).to eq date_array
       end
     end
 
@@ -537,26 +528,26 @@ describe Timeliness::Parser do
       it 'should return date array for utc zone' do
         time = Time.now.getutc
         date_array = [time.year, time.month, time.day]
-        expect(current_date(:zone => :utc)).to eq date_array
+        expect(current_date(zone: :utc)).to eq date_array
       end
 
       it 'should return date array for local zone' do
         time = Time.now
         date_array = [time.year, time.month, time.day]
-        expect(current_date(:zone => :local)).to eq date_array
+        expect(current_date(zone: :local)).to eq date_array
       end
 
       it 'should return date array for current zone' do
         Time.zone = 'London'
         time = Time.current
         date_array = [time.year, time.month, time.day]
-        expect(current_date(:zone => :current)).to eq date_array
+        expect(current_date(zone: :current)).to eq date_array
       end
 
       it 'should return date array for named zone' do
         time = Time.use_zone('London') { Time.current }
         date_array = [time.year, time.month, time.day]
-        expect(current_date(:zone => 'London')).to eq date_array
+        expect(current_date(zone: 'London')).to eq date_array
       end
     end
   end
